'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const ModuleFilenameHelpers = require('webpack/lib/ModuleFilenameHelpers');
const os = require('os');
const path = require('path');
const fs = require('fs');

class JSXBinWebpackPlugin {
  constructor(options) {
    if (typeof options !== 'object') {
      throw new TypeError('Argument "options" must be an object.');
    }
    this.test = options.test;
    try {
      this.jsxbin = require('jsxbin');
    } catch (err) {
      console.warn('jsxbin package not found. Not compiling jsx assets.');
      this.jsxbin = null;
    }
  }

  _compileFile(compilation, fileName) {
    var _this = this;

    return _asyncToGenerator(function* () {
      const jsxFilename = fileName.replace('.js', '.jsxbin');
      const temporaryJSDestination = path.join(os.tmpdir(), fileName);
      const temporaryJSXDestination = path.join(os.tmpdir(), jsxFilename);
      if (fs.existsSync(temporaryJSDestination)) {
        fs.unlinkSync(temporaryJSDestination);
      }
      if (fs.existsSync(temporaryJSXDestination)) {
        fs.unlinkSync(temporaryJSXDestination);
      }
      fs.writeFileSync(temporaryJSDestination, compilation.assets[fileName].source());
      yield _this.jsxbin(temporaryJSDestination, temporaryJSXDestination);
      const jsxContents = fs.readFileSync(temporaryJSXDestination, 'utf8');
      fs.unlinkSync(temporaryJSXDestination);
      compilation.assets[jsxFilename] = {
        source: function source() {
          return jsxContents;
        },
        size: function size() {
          return jsxContents.length;
        }
      };
      delete compilation.assets[fileName];
    })();
  }

  _compileChunks(compilation, chunks) {
    var _this2 = this;

    return _asyncToGenerator(function* () {
      const promises = [];
      chunks.forEach(function (chunk) {
        chunk.files.forEach(function (fileName) {
          if (ModuleFilenameHelpers.matchObject({ test: _this2.test }, fileName)) {
            promises.push(_this2._compileFile(compilation, fileName));
          }
        });
      });

      return Promise.all(promises);
    })();
  }

  apply(compiler) {
    if (this.jsxbin) {
      compiler.plugin('compilation', compilation => {
        compilation.plugin('optimize-chunk-assets', (chunks, done) => {
          this._compileChunks(compilation, chunks).then(() => {
            done();
          });
        });
      });
    }
  }
}

module.exports = JSXBinWebpackPlugin;